@@ -4,12 +4,12 @@ BEGIN {
   $Task::MusicBundle::AUTHORITY = 'cpan:GENE';
 }
 
-# ABSTRACT: A bundle of MIDI and music modules
+# ABSTRACT: MIDI and music creation modules
 
 use strict;
 use warnings;
 
-our $VERSION = '0.1906';
+our $VERSION = '0.1907';
 
 1;
 
@@ -21,11 +21,11 @@ __END__
 
 =head1 NAME
 
-Task::MusicBundle - A bundle of MIDI and music modules
+Task::MusicBundle - MIDI and music creation modules
 
 =head1 VERSION
 
-version 0.1906
+version 0.1907
 
 =head1 SYNOPSIS
 
@@ -39,16 +39,15 @@ version 0.1906
 
 =head1 DESCRIPTION
 
-This is a bundle to install various MIDI and Music related to the
-creation of music.  This is B<not> a bundle of B<all> the MIDI and
+This is a bundle to install various MIDI and Music modules related to
+the creation of music.  This is B<not> a bundle of B<all> the MIDI and
 Music modules out there.  Analysis, lyrics, notation, and tablature
 things are not included.
 
 If you would like to see a specific module included (or discluded),
 please email me or use rt.cpan.org.
 
-At this initial writing modules marked with a date, in the
-C<CONTENTS>, are 10 years or older. But so what?
+Some modules in the C<CONTENTS> are 10 years or older. But so what?
 B<Music is older than agriculture>.
 
 =head1 CONTENTS
